@@ -58,6 +58,8 @@ class TraderAgent(AgentBase):
             if (key != 'block_num') & (self.wallet[key][-1] < 0):
                 if not self.protocol.warning_only:
                     raise UserWarning(f'Error. {key} balance cannot be less than zero. {self.wallet[key][-1]}')
+                else:
+                    f'Warning. {key} balance should not be less than zero. {self.wallet[key][-1]}'
 
     def get_wallet(self):
         return pd.DataFrame.from_dict(self.wallet)
