@@ -24,5 +24,7 @@ from .data_utils import (
 )
 from .schemas import (
     FixedPointUnstakeTKN,
-    FloatingPointUnstakeTKN
+    FloatingPointUnstakeTKN,
+    FixedPointGeneral,
+    FloatingPointGeneral
 )
\ No newline at end of file
